@@ -16,10 +16,8 @@ bracketing <- function(fun, interval, ...,
     if (!is.null(cl)) method <- "snow"
     if (method == "multicore") {
         if (!suppressWarnings(require("parallel", quietly = TRUE))) {
-            message("package 'parallel' is used")
-        } else if (!suppressWarnings(require("multicore", quietly = TRUE))) {
             method <- "loop"
-            warning("package 'multicore' not available: use method 'loop'")
+            warning("package 'parallel' not available: use method 'loop'")
         }
     } else if (method == "snow") {
         if (!suppressWarnings(require("snow", quietly = TRUE))) {
